@@ -1,11 +1,10 @@
 #!/bin/sh
 
-DIR_SCRIPT="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"  # absolute path to the dir of this script
-source $DIR_SCRIPT/config.sh   # check for important paramters
+source $QMSDEVDIR/qmapshack/MacOSX/config.sh   # check for important paramters
 
 # Bundling QMapShack and QMapTool
 echo "${INFO}Bundle QMapShack ...${NC}"
-mkdir $BUILD_RELEASE_DIR
+mkdir -p $BUILD_RELEASE_DIR
 cd $SRC_OSX_DIR
 source ./bundle-qmapshack.sh
 cd $SRC_OSX_DIR
