@@ -1,8 +1,7 @@
 #!/bin/sh
 
 # Create a local environment for all includes, libs, ... needed
-DIR_SCRIPT="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"  # absolute path to the dir of this script
-source $DIR_SCRIPT/config.sh   # check for important paramters
+source $QMSDEVDIR/qmapshack/MacOSX/config.sh   # check for important paramters
 
 mkdir $LOCAL_ENV
 mkdir $LOCAL_ENV/bin
