@@ -179,7 +179,7 @@ CMainWindow::CMainWindow() : id(QRandomGenerator::global()->generate()) {
   connect(actionWiki, &QAction::triggered, this, &CMainWindow::slotWiki);
   connect(actionHelp, &QAction::triggered, this, &CMainWindow::slotHelp);
   connect(actionQuickstart, &QAction::triggered, this, &CMainWindow::slotQuickstart);
-  connect(actionAddMapView, &QAction::triggered, this, [this]() { slotAddCanvas(""); });
+  connect(actionAddMapView, &QAction::triggered, this, &CMainWindow::slotAddMapView);
   connect(actionCloneMapView, &QAction::triggered, this, &CMainWindow::slotCloneCanvas);
   connect(actionShowGrid, &QAction::changed, this, [this]() { this->update(); });
   connect(actionShowScale, &QAction::changed, this, &CMainWindow::slotUpdateTabWidgets);
@@ -242,16 +242,18 @@ CMainWindow::CMainWindow() : id(QRandomGenerator::global()->generate()) {
   const QStringList& names = cfg.childGroups();
 
   for (const QString& name : names) {
-    CCanvas* view = addView(name);
+    CCanvas* view = createCanvas(name);
 
     cfg.beginGroup(name);
     view->loadConfig(cfg);
     cfg.endGroup();  // name
   }
   if (names.isEmpty()) {
-    CCanvas* view = addView(QString());
+    CCanvas* view = createCanvas(QString());
     // call just to setup default values
+    cfg.beginGroup(view->objectName());
     view->loadConfig(cfg);
+    cfg.endGroup();
   }
   cfg.endGroup();  // Views
   testForNoView();
@@ -623,7 +625,7 @@ void CMainWindow::setupHomePath() {
   cfg.setValue("Paths/homePath", homeDir.absolutePath());
 }
 
-CCanvas* CMainWindow::addView(const QString& name) {
+CCanvas* CMainWindow::createCanvas(const QString& name) {
   CCanvas* view = new CCanvas(tabWidget, name);
   tabWidget->addTab(view, view->objectName());
   connect(view, &CCanvas::sigMousePosition, this, &CMainWindow::slotMousePosition);
@@ -747,15 +749,15 @@ void CMainWindow::resetMouse() {
   }
 }
 
-qreal CMainWindow::getElevationAt(const QPointF& pos) const {
+qreal CMainWindow::getElevationAt(const QPointF& pos, bool checkScale) const {
   CCanvas* canvas = getVisibleCanvas();
   if (canvas) {
-    return canvas->getElevationAt(pos);
+    return canvas->getElevationAt(pos, checkScale);
   } else {
     for (int i = 0; i < tabWidget->count(); i++) {
       canvas = dynamic_cast<CCanvas*>(tabWidget->widget(i));
       if (canvas) {
-        return canvas->getElevationAt(pos);
+        return canvas->getElevationAt(pos, checkScale);
       }
     }
   }
@@ -854,12 +856,12 @@ void CMainWindow::slotQuickstart() {
   }
 }
 
-void CMainWindow::slotAddCanvas(const QString& name) {
-  CCanvas* view = addView(name);
-  tabWidget->setCurrentWidget(view);
-
+CCanvas* CMainWindow::addCanvas(const QString& name) {
+  CCanvas* canvas = createCanvas(name);
+  tabWidget->setCurrentWidget(canvas);
   testForNoView();
   emit sigCanvasChange();
+  return canvas;
 }
 
 void CMainWindow::slotCloneCanvas() {
@@ -869,29 +871,24 @@ void CMainWindow::slotCloneCanvas() {
   }
 
   QTemporaryFile temp;
-  openFileCheckSuccess(QIODevice::ReadWrite, temp);
-  temp.close();
-
   QSettings view(temp.fileName(), QSettings::IniFormat);
   view.clear();
 
   source->saveConfig(view);
 
-  slotAddCanvas(source->objectName() + tr(" (Cloned)"));
-
-  CCanvas* target = getVisibleCanvas();
-  if (nullptr == target) {
+  CCanvas* canvas = addCanvas(source->objectName() + tr(" (Cloned)"));
+  if (nullptr == canvas) {
     return;
   }
 
-  target->loadConfig(view);
-  target->slotTriggerCompleteUpdate(CCanvas::redraw_e::eRedrawGis);
+  canvas->loadConfig(view);
+  canvas->slotTriggerCompleteUpdate(CCanvas::redraw_e::eRedrawGis);
 
   SETTINGS;
   cfg.beginGroup("Canvas");
   cfg.beginGroup("Views");
-  cfg.beginGroup(target->objectName());
-  target->saveConfig(cfg);
+  cfg.beginGroup(canvas->objectName());
+  canvas->saveConfig(cfg);
   cfg.endGroup();
   cfg.endGroup();
   cfg.endGroup();
@@ -1227,9 +1224,7 @@ void CMainWindow::slotLoadView() {
   QSettings view(filename, QSettings::IniFormat);
 
   const QString& name = view.value("name", QString()).toString();
-  slotAddCanvas(name);
-
-  CCanvas* canvas = getVisibleCanvas();
+  CCanvas* canvas = addCanvas(name);
   if (nullptr == canvas) {
     return;
   }
@@ -1652,6 +1647,23 @@ void CMainWindow::slotLinkMapViews(bool on) {
   }
 }
 
+void CMainWindow::slotAddMapView() {
+  // call with empty name to get a unique default name
+  CCanvas* canvas = addCanvas("");
+  if (nullptr == canvas) {
+    return;
+  }
+
+  SETTINGS;
+  cfg.beginGroup("Canvas");
+  cfg.beginGroup("Views");
+  cfg.beginGroup(canvas->objectName());
+  canvas->loadConfig(cfg);
+  cfg.endGroup();
+  cfg.endGroup();
+  cfg.endGroup();
+}
+
 bool CMainWindow::eventFilter(QObject* obj, QEvent* event) {
   if (event->type() == QEvent::FileOpen) {
     QFileOpenEvent* openEvent = static_cast<QFileOpenEvent*>(event);
