@@ -50,12 +50,24 @@ class CMainWindow : public QMainWindow, private Ui::IMainWindow {
 
   QString getHomePath() { return (homeDir.path() != "" && homeDir.exists()) ? homeDir.absolutePath() : ""; }
 
-  QString getMapsPath() { return (homeDir.path() != "" && homeDir.exists(mapsPath)) ? homeDir.absoluteFilePath(mapsPath) : ""; }
-  QString getDemPath() { return (homeDir.path() != "" && homeDir.exists(demPath)) ? homeDir.absoluteFilePath(demPath) : ""; }
-  QString getRoutinoPath() { return (homeDir.path() != "" && homeDir.exists(routinoPath)) ? homeDir.absoluteFilePath(routinoPath) : ""; }
-  QString getBRouterPath() { return (homeDir.path() != "" && homeDir.exists(brouterPath)) ? homeDir.absoluteFilePath(brouterPath) : ""; }
-  QString getDatabasePath() { return (homeDir.path() != "" && homeDir.exists(databasePath)) ? homeDir.absoluteFilePath(databasePath) : ""; }
-  QString getGpxPath() { return (homeDir.path() != "" && homeDir.exists(gpxPath)) ? homeDir.absoluteFilePath(gpxPath) : ""; }
+  QString getMapsPath() {
+    return (homeDir.path() != "" && homeDir.exists(mapsPath)) ? homeDir.absoluteFilePath(mapsPath) : "";
+  }
+  QString getDemPath() {
+    return (homeDir.path() != "" && homeDir.exists(demPath)) ? homeDir.absoluteFilePath(demPath) : "";
+  }
+  QString getRoutinoPath() {
+    return (homeDir.path() != "" && homeDir.exists(routinoPath)) ? homeDir.absoluteFilePath(routinoPath) : "";
+  }
+  QString getBRouterPath() {
+    return (homeDir.path() != "" && homeDir.exists(brouterPath)) ? homeDir.absoluteFilePath(brouterPath) : "";
+  }
+  QString getDatabasePath() {
+    return (homeDir.path() != "" && homeDir.exists(databasePath)) ? homeDir.absoluteFilePath(databasePath) : "";
+  }
+  QString getGpxPath() {
+    return (homeDir.path() != "" && homeDir.exists(gpxPath)) ? homeDir.absoluteFilePath(gpxPath) : "";
+  }
 
   static QString getUser();
 
@@ -91,7 +103,7 @@ class CMainWindow : public QMainWindow, private Ui::IMainWindow {
      @param pos   a position in units of [rad]
      @return If no elevation value can be found for the position NOFLOAT is returned.
    */
-  qreal getElevationAt(const QPointF& pos) const;
+  qreal getElevationAt(const QPointF& pos, bool checkScale) const;
   void getElevationAt(const QPolygonF& pos, QPolygonF& ele) const;
   void getElevationAt(SGisLine& line) const;
 
@@ -135,7 +147,6 @@ class CMainWindow : public QMainWindow, private Ui::IMainWindow {
   void slotAbout();
   void slotWiki();
   void slotQuickstart();
-  void slotAddCanvas(const QString& name);
   void slotCloneCanvas();
   void slotTabCloseRequest(int i);
   void slotCurrentTabCanvas(int i);
@@ -163,7 +174,6 @@ class CMainWindow : public QMainWindow, private Ui::IMainWindow {
   void slotCreateRoutinoDatabase();
   void slotPrintMap();
   void slotTakeScreenshot();
-  void slotSetupWptIcons();
   void slotSanityTest();
   void slotCloseTab();
   void slotToggleDocks();
@@ -176,6 +186,7 @@ class CMainWindow : public QMainWindow, private Ui::IMainWindow {
   void slotHelp();
   void slotMapMoveAndZoom(int idx, const QPointF& focus);
   void slotLinkMapViews(bool on);
+  void slotAddMapView();
 
  private:
   friend int main(int argc, char** argv);
@@ -187,8 +198,9 @@ class CMainWindow : public QMainWindow, private Ui::IMainWindow {
   void hideDocks();
   void displayRegular();
   void displayFullscreen();
-  CCanvas* addView(const QString& name);
+  CCanvas* createCanvas(const QString& name);
   void setupHomePath();
+  CCanvas* addCanvas(const QString& name);
 
   static CMainWindow* pSelf;
   static QDir homeDir;
