@@ -114,6 +114,8 @@ class IDrawContext : public QThread {
 
   const QPointF& getZoomFactor() const { return zoomFactor; }
 
+  QPointF getScale() const;
+
   /**
      @brief Set the projection of the draw context
 
@@ -130,6 +132,8 @@ class IDrawContext : public QThread {
 
   virtual void setScales(const CCanvas::scales_type_e type);
 
+  CCanvas* getCanvas() { return canvas; }
+
  signals:
   void sigCanvasUpdate(CCanvas::redraw_e flags);
   void sigStartThread();
@@ -164,7 +168,7 @@ class IDrawContext : public QThread {
   bool intNeedsRedraw;
 
   /// the canvas this map object is attached to
-  CCanvas* canvas;
+  QPointer<CCanvas> canvas;
 
   const CCanvas::redraw_e maskRedraw;
   /// map canvas twin buffer
