@@ -19,11 +19,13 @@
 #ifndef CDEMDRAW_H
 #define CDEMDRAW_H
 
+#include <QStringList>
+
 #include "canvas/IDrawContext.h"
 
 class QPainter;
-class CDemList;
 class CCanvas;
+class CDemList;
 class QSettings;
 class CDemItem;
 
@@ -34,25 +36,17 @@ class CDemDraw : public IDrawContext {
 
   void saveConfig(QSettings& cfg);
   void loadConfig(QSettings& cfg);
-  /**
-     @brief This is called most likely from the item itself to call it's loadConfig() method.
 
-     As the setup of a map is stored in the context of the view the correct groups have
-     to be set prior to call the item's loadConfig() method. However the item does not know
-     all that stuff. That is why it has to ask it's CMapDraw object to prepare the QSettings object
-     and to call loadConfig();
-
-     @param item the item to call it's loadConfig() method
-   */
-  void loadConfigForDemItem(CDemItem* item);
-
-  qreal getElevationAt(const QPointF& pos, bool checkScale = false);
+  qreal getElevationAt(const QPointF& pos, bool checkScale);
   void getElevationAt(const QPolygonF& pos, QPolygonF& ele);
   void getElevationAt(SGisLine& line);
-
   qreal getSlopeAt(const QPointF& pos, bool checkScale = false);
   void getSlopeAt(const QPolygonF& pos, QPolygonF& slope);
 
+  /**
+     @brief Set projection of this draw context
+     @param proj      a proj4 string
+   */
   bool setProjection(const QString& proj) override;
 
   static const QStringList& getDemPaths() { return demPaths; }
@@ -67,31 +61,61 @@ class CDemDraw : public IDrawContext {
  protected:
   void drawt(buffer_t& currentBuffer) override;
 
+ private slots:
+  void slotChanged();
+  void saveDemList();
+
  private:
   /**
-     @brief Search in paths found in mapPaths for files with supported extensions and add them to mapList.
+     @brief Create a CDemItem from a filename
 
-   */
-  void buildMapList();
+    @param filename    the DEM's filename, can be a resuource, too
+    @param fallbackKey a fallback key used if no key can be derived from the file
+
+    @return The created map item.
+  */
+  CDemItem* createDemItem(const QString& filename, const QString& fallbackKey);
 
   /**
-     @brief Save list of active maps to configuration file
+     @brief Load the list of DEMs including all configurations
+
+   This will parse the map paths for map file and compare it with the
+   stored list of map keys in the config. Based on that a list of active,
+   inactive, new and missing DEM is created. If possible the last configuration
+   of a map is restored.
+
    */
-  void saveActiveMapsList(QStringList& keys, QSettings& cfg);
-  void saveActiveMapsList(QStringList& keys);
+  void loadDemList(QSettings& cfg);
+
   /**
-     @brief Restore list of active maps from configuration file
+   * @brief Load DEM list with configuration from the application's settings.
    */
-  void restoreActiveMapsList(const QStringList& keys);
-  void restoreActiveMapsList(const QStringList& keys, QSettings& cfg);
+  void loadDemList();
+
+  /**
+     @brief Store the list of DEMs including all configurations
+
+   This will iterate of the list of DEMs, store their configuration
+   and store all keys in the same order as the list.
+
+   */
+  void saveDemList(QSettings& cfg);
 
   CDemList* demList;
 
-  /// the group label used in QSettings
-  QString cfgGroup;
+  /**
+   *  @brief delay timer to save config after a change
+   *
+   * This is used to combine multiple change signals within a second
+   * and to give saving a cool down time if anything crashes on
+   * a change.
+   */
+  QTimer* timerDelayedSave;
 
+  /// the list of paths to search maps
   static QStringList demPaths;
 
+  /// all existing CDemDraw instances
   static QList<CDemDraw*> dems;
 
   /// a list of supported map formats
