@@ -30,7 +30,6 @@ CDemPathSetup::CDemPathSetup(QStringList& paths) : QDialog(CMainWindow::getBestW
   connect(toolAdd, &QToolButton::clicked, this, &CDemPathSetup::slotAddPath);
   connect(toolDelete, &QToolButton::clicked, this, &CDemPathSetup::slotDelPath);
   connect(listWidget, &QListWidget::itemSelectionChanged, this, &CDemPathSetup::slotItemSelectionChanged);
-  connect(pushDemHonk, &QPushButton::clicked, this, &CDemPathSetup::slotDemHonk);
 
   for (const QString& path : paths) {
     QListWidgetItem* item = new QListWidgetItem(listWidget);
@@ -64,11 +63,6 @@ void CDemPathSetup::slotDelPath() {
   qDeleteAll(items);
 }
 
-void CDemPathSetup::slotDemHonk() {
-  CDemList::slotDemHonk();
-  close();
-}
-
 void CDemPathSetup::accept() {
   paths.clear();
   for (int i = 0; i < listWidget->count(); i++) {
