@@ -18,9 +18,4 @@
 
 #include "dem/CDemWCS.h"
 
-CDemWCS::CDemWCS(const QString& filename, CDemDraw* parent)
-    : CDemVRT(filename, parent)
-{
-}
-
-
+CDemWCS::CDemWCS(const QString& filename, CDemDraw* parent) : CDemVRT(filename, parent) {}
