@@ -27,7 +27,7 @@
 #include "gis/gpx/CGpxProject.h"
 
 CDeviceGarminArchive::CDeviceGarminArchive(const QString& path, CDeviceGarmin* parent)
-    : IDevice(path, eTypeGarmin, parent->getKey(), parent) {
+    : IDevice(path, parent->getKey(), parent) {
   setText(CGisListWks::eColumnName, tr("Archive - expand to load"));
   setChildIndicatorPolicy(QTreeWidgetItem::ShowIndicator);
   connect(treeWidget(), &QTreeWidget::itemExpanded, this, &CDeviceGarminArchive::slotExpanded);
@@ -47,7 +47,7 @@ void CDeviceGarminArchive::slotExpanded(QTreeWidgetItem* item) {
   qDebug() << "reading files from device: " << dir.path();
   const QStringList& entries = dir.entryList(QStringList("*.gpx"));
   for (const QString& entry : entries) {
-    const QString filename = dir.absoluteFilePath(entry);
+    const QString& filename = dir.absoluteFilePath(entry);
     IGisProject* project = new CGpxProject(filename, this);
     if (!project->isValid()) {
       delete project;
