@@ -506,11 +506,11 @@ class IGisItem : public QTreeWidgetItem {
   const static QString noName;
 
   struct color_t {
-    const char* name;
-    const QString label;
-    const QColor color;
-    const QString bullet;
-    const QString line;
+    QString name;
+    QString label;
+    QColor color;
+    QString bullet;
+    QString line;
   };
 
   static const QVector<color_t>& getColorMap() { return colorMap; }
