@@ -40,12 +40,12 @@ SGisLine::SGisLine(const QPolygonF& line) {
 void SGisLine::updateElevation(CDemDraw* dem) {
   for (int i = 0; i < size(); i++) {
     IGisLine::point_t& pt = (*this)[i];
-    qreal ele = dem->getElevationAt(pt.coord);
+    qreal ele = dem->getElevationAt(pt.coord, false);
     pt.ele = (ele == NOFLOAT) ? NOINT : qRound(ele);
 
     for (int n = 0; n < pt.subpts.size(); n++) {
       IGisLine::subpt_t& sub = pt.subpts[n];
-      qreal ele = dem->getElevationAt(sub.coord);
+      qreal ele = dem->getElevationAt(sub.coord, false);
       sub.ele = (ele == NOFLOAT) ? NOINT : qRound(ele);
     }
   }
