@@ -40,8 +40,9 @@ void CExportDatabaseThread::start(const QString& path, bool saveAsGpx11) {
 }
 
 QString CExportDatabaseThread::simplifyString(const QString& str) const {
+  static const QRegularExpression re("[^\\w\\d]");
   QString s = str;
-  return s.replace(QRegExp("[^\\w\\d]"), "_");
+  return s.replace(re, "_");
 }
 
 void CExportDatabaseThread::slotAbort() {
