@@ -133,7 +133,7 @@ QPointF CGisItemOvlArea::getPointCloseBy(const QPoint& screenPos) {
   qint32 i = 0;
   qint32 idx = NOIDX;
   qint32 d = NOINT;
-  for (const QPointF& point : qAsConst(polygonArea)) {
+  for (const QPointF& point : std::as_const(polygonArea)) {
     int tmp = (screenPos - point).manhattanLength();
     if (tmp < d) {
       idx = i;
@@ -185,7 +185,7 @@ void CGisItemOvlArea::deriveSecondaryData() {
   qreal south = 90;
   qreal west = 180;
 
-  for (const pt_t& pt : qAsConst(area.pts)) {
+  for (const pt_t& pt : std::as_const(area.pts)) {
     if (pt.lon < west) {
       west = pt.lon;
     }
@@ -238,7 +238,7 @@ void CGisItemOvlArea::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRe
 
   QPointF pt1;
 
-  for (const pt_t& pt : qAsConst(area.pts)) {
+  for (const pt_t& pt : std::as_const(area.pts)) {
     pt1.setX(pt.lon);
     pt1.setY(pt.lat);
     pt1 *= DEG_TO_RAD;
@@ -342,12 +342,12 @@ QString CGisItemOvlArea::getInfo(quint32 feature) const {
   str += "<br/>\n" + tr("Area: %1%2").arg(val, unit);
 
   QString desc = removeHtml(area.desc).simplified();
-  if (desc.count()) {
+  if (desc.length()) {
     if (!str.isEmpty()) {
       str += "<br/>\n";
     }
 
-    if ((feature & eFeatureShowFullText) || (desc.count() < 300)) {
+    if ((feature & eFeatureShowFullText) || (desc.length() < 300)) {
       str += desc;
     } else {
       str += desc.left(297) + "...";
@@ -355,12 +355,12 @@ QString CGisItemOvlArea::getInfo(quint32 feature) const {
   }
 
   QString cmt = removeHtml(area.cmt).simplified();
-  if ((cmt != desc) && cmt.count()) {
+  if ((cmt != desc) && cmt.length()) {
     if (!str.isEmpty()) {
       str += "<br/>\n";
     }
 
-    if ((feature & eFeatureShowFullText) || (cmt.count() < 300)) {
+    if ((feature & eFeatureShowFullText) || (cmt.length() < 300)) {
       str += cmt;
     } else {
       str += cmt.left(297) + "...";
