@@ -23,12 +23,14 @@
 #include <QtWidgets>
 
 #include "CMainWindow.h"
+#include "device/CDeviceGarminMtp.h"
+#include "device/CDeviceGenericMtp.h"
 #include "device/IDevice.h"
 #include "gis/CGisDraw.h"
 #include "gis/CGisListWks.h"
 #include "gis/CGisWorkspace.h"
 #include "gis/IGisItem.h"
-#include "gis/fit/CFitProject.h"
+#include "gis/fit2/CFit2Project.h"
 #include "gis/gpx/CGpxProject.h"
 #include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/prj/CDetailsPrj.h"
@@ -120,7 +122,7 @@ IGisProject* IGisProject::create(const QString filename, CGisListWks* parent) {
       parent->addProject(item);
     }
   } else if (suffix == "fit") {
-    item = new CFitProject(filename, parent);
+    item = new CFit2Project(filename, parent);
   } else if (suffix == "tcx") {
     item = new CTcxProject(filename, parent);
   } else if (suffix == "sml") {
@@ -140,7 +142,9 @@ IGisProject* IGisProject::create(const QString filename, CGisListWks* parent) {
 }
 
 QString IGisProject::html2Dev(const QString& str) {
-  return isOnDevice() == IDevice::eTypeGarmin ? IGisItem::removeHtml(str) : str;
+  return (isOnDevice() == IDevice::eTypeGarmin)
+                 || (isOnDevice() == IDevice::eTypeGarminMtp)
+                 || (isOnDevice() == IDevice::eTypeGenericMtp) ? IGisItem::removeHtml(str) : str;
 }
 
 bool IGisProject::askBeforClose() {
@@ -467,7 +471,7 @@ QString IGisProject::getInfo() const {
   if (!desc.isEmpty()) {
     str += "<br/>\n";
 
-    if (desc.count() < 100) {
+    if (desc.length() < 100) {
       str += desc;
     } else {
       str += desc.left(97) + "...";
@@ -783,6 +787,18 @@ void IGisProject::umount() {
 }
 
 bool IGisProject::remove() {
+#ifdef Q_OS_LINUX
+  CDeviceGarminMtp* mtpGarmin = dynamic_cast<CDeviceGarminMtp*>(parent());
+  if (mtpGarmin != nullptr) {
+    return mtpGarmin->removeFromDevice(filename);
+  } else {
+    CDeviceGenericMtp* mtpGeneric = dynamic_cast<CDeviceGenericMtp*>(parent());
+    if (mtpGeneric != nullptr) {
+      return mtpGeneric->removeFromDevice(filename);
+    }
+  }
+#endif
+
   CProjectMountLock mountLock(*this);
 
   /*
@@ -893,7 +909,7 @@ void IGisProject::sortItems() {
 
   QList<QTreeWidgetItem*> items = takeChildren();
   QList<QTreeWidgetItem*> others;  // For example Search
-  for (QTreeWidgetItem* item : qAsConst(items)) {
+  for (QTreeWidgetItem* item : std::as_const(items)) {
     CGisItemTrk* trk = dynamic_cast<CGisItemTrk*>(item);
     if (trk != nullptr) {
       trks << trk;
@@ -928,16 +944,16 @@ void IGisProject::sortItems() {
 
   items.clear();
   items << others;
-  for (IGisItem* item : qAsConst(trks)) {
+  for (IGisItem* item : std::as_const(trks)) {
     items << item;
   }
-  for (IGisItem* item : qAsConst(rtes)) {
+  for (IGisItem* item : std::as_const(rtes)) {
     items << item;
   }
-  for (IGisItem* item : qAsConst(wpts)) {
+  for (IGisItem* item : std::as_const(wpts)) {
     items << item;
   }
-  for (IGisItem* item : qAsConst(ovls)) {
+  for (IGisItem* item : std::as_const(ovls)) {
     items << item;
   }
 
