@@ -21,30 +21,19 @@
 
 #include "gis/prj/IGisProject.h"
 
-class CQmsProject : public IGisProject
-{
-    Q_DECLARE_TR_FUNCTIONS(CQmsProject)
-public:
-    CQmsProject(const QString& filename, CGisListWks* parent);
-    virtual ~CQmsProject() = default;
+class CQmsProject : public IGisProject {
+  Q_DECLARE_TR_FUNCTIONS(CQmsProject)
+ public:
+  CQmsProject(const QString& filename, CGisListWks* parent);
+  virtual ~CQmsProject() = default;
 
-    const QString getFileDialogFilter() const override
-    {
-        return IGisProject::filedialogFilterQMS;
-    }
+  const QString getFileDialogFilter() const override { return IGisProject::filedialogFilterQMS; }
 
-    const QString getFileExtension() const override
-    {
-        return "qms";
-    }
+  const QString getFileExtension() const override { return "qms"; }
 
-    bool canSave() const override
-    {
-        return true;
-    }
+  bool canSave() const override { return true; }
 
-    static bool saveAs(const QString& fn, IGisProject& project);
+  static bool saveAs(const QString& fn, IGisProject& project);
 };
 
-#endif //CQMSPROJECT_H
-
+#endif  // CQMSPROJECT_H
