@@ -19,27 +19,24 @@
 #ifndef CCREATEROUTEFROMWPT_H
 #define CCREATEROUTEFROMWPT_H
 
-#include "gis/IGisItem.h"
-
-#include "ui_ICreateRouteFromWpt.h"
 #include <QDialog>
 
+#include "gis/IGisItem.h"
+#include "ui_ICreateRouteFromWpt.h"
 
-class CCreateRouteFromWpt : public QDialog, private Ui::ICreateRouteFromWpt
-{
-    Q_OBJECT
-public:
-    CCreateRouteFromWpt(const QList<IGisItem::key_t>& keys, QWidget* parent);
-    virtual ~CCreateRouteFromWpt();
+class CCreateRouteFromWpt : public QDialog, private Ui::ICreateRouteFromWpt {
+  Q_OBJECT
+ public:
+  CCreateRouteFromWpt(const QList<IGisItem::key_t>& keys, QWidget* parent);
+  virtual ~CCreateRouteFromWpt();
 
-public slots:
-    void accept() override;
+ public slots:
+  void accept() override;
 
-private slots:
-    void slotSelectionChanged();
-    void slotUp();
-    void slotDown();
+ private slots:
+  void slotSelectionChanged();
+  void slotUp();
+  void slotDown();
 };
 
-#endif //CCREATEROUTEFROMWPT_H
-
+#endif  // CCREATEROUTEFROMWPT_H
