@@ -82,8 +82,6 @@ CRouterBRouter::CRouterBRouter(QWidget* parent) : IRouter(false, parent) {
 
   cfg.beginGroup("Route/brouter");
   comboProfile->setCurrentIndex(cfg.value("profile", 0).toInt());
-  checkFastRecalc->setChecked(cfg.value("fastRecalc", false).toBool() &&
-                              (setup->installMode == CRouterBRouterSetup::eModeLocal));
   comboAlternative->setCurrentIndex(cfg.value("alternative", 0).toInt());
   cfg.endGroup();
 }
@@ -97,7 +95,6 @@ CRouterBRouter::~CRouterBRouter() {
   cfg.beginGroup("Route/brouter");
   cfg.setValue("profile", comboProfile->currentIndex());
   cfg.setValue("alternative", comboAlternative->currentIndex());
-  cfg.setValue("fastRecalc", checkFastRecalc->isChecked());
   cfg.endGroup();
 }
 
@@ -188,14 +185,14 @@ void CRouterBRouter::slotCloseStatusMsg() const {
 
 QString CRouterBRouter::getOptions() {
   return QString(tr("profile: %1, alternative: %2")
-                     .arg(comboProfile->currentData().toString())
-                     .arg(comboAlternative->currentData().toInt() + 1));
+                     .arg(comboProfile->currentText())
+                     .arg(comboAlternative->currentData().toInt()));
 }
 
 void CRouterBRouter::routerSelected() { getBRouterVersion(); }
 
 bool CRouterBRouter::hasFastRouting() {
-  return setup->installMode == CRouterBRouterSetup::eModeLocal && setup->isLocalBRouterValid && checkFastRecalc->isChecked();
+  return setup->installMode == CRouterBRouterSetup::eModeLocal && setup->isLocalBRouterValid;
 }
 
 QNetworkRequest CRouterBRouter::getRequest(const QVector<QPointF>& routePoints, const QList<IGisItem*>& nogos) const {
@@ -235,7 +232,7 @@ QNetworkRequest CRouterBRouter::getRequest(const QVector<QPointF>& routePoints,
         QPolygonF polygon;
         line->getPolylineDegFromData(polygon);
         QString nogoPoints;
-        for (const QPointF point : qAsConst(polygon)) {
+        for (const QPointF point : std::as_const(polygon)) {
           if (!nogoPoints.isEmpty()) {
             nogoPoints.append(",");
           }
@@ -275,6 +272,7 @@ QNetworkRequest CRouterBRouter::getRequest(const QVector<QPointF>& routePoints,
   urlQuery.addQueryItem("profile", comboProfile->currentData().toString());
   urlQuery.addQueryItem("alternativeidx", comboAlternative->currentData().toString());
   urlQuery.addQueryItem("format", "gpx");
+  urlQuery.addQueryItem("timode", "8");
 
   QUrl url = setup->getServiceUrl();
   url.setQuery(urlQuery);
@@ -340,7 +338,7 @@ int CRouterBRouter::synchronousRequest(const QVector<QPointF>& points, const QLi
     const QDomElement& xmlGpx = xml.documentElement();
 
     if (xmlGpx.isNull() || xmlGpx.tagName() != "gpx") {
-      throw QString(res);
+      throw QString(res.data());
     }
     setup->parseBRouterVersion(xmlGpx.attribute("creator"));
 
@@ -365,13 +363,13 @@ int CRouterBRouter::synchronousRequest(const QVector<QPointF>& points, const QLi
         }
         const QString& commentTxt = node.toComment().data();
         // ' track-length = 180864 filtered ascend = 428 plain-ascend = -172 cost=270249 '
-        const QRegExp rxAscDes(
+        static const QRegularExpression rxAscDes(
             "(\\s*track-length\\s*=\\s*)(-?\\d+)(\\s*)(filtered "
             "ascend\\s*=\\s*-?\\d+)(\\s*)(plain-ascend\\s*=\\s*-?\\d+)(\\s*)(cost\\s*=\\s*)(-?\\d+)(\\s*)");
-        int pos = rxAscDes.indexIn(commentTxt);
-        if (pos > -1) {
+        const QRegularExpressionMatch& match = rxAscDes.match(commentTxt);
+        if (match.hasMatch()) {
           bool ok;
-          *costs = rxAscDes.cap(9).toDouble(&ok);
+          *costs = match.captured(9).toDouble(&ok);
           if (!ok) {
             *costs = -1;
           }
@@ -468,7 +466,7 @@ void CRouterBRouter::slotRequestFinished(QNetworkReply* reply) {
 
     const QDomElement& xmlGpx = xml.documentElement();
     if (xmlGpx.isNull() || xmlGpx.tagName() != "gpx") {
-      throw QString(res);
+      throw QString(res.data());
     }
 
     IGisItem::key_t key;
@@ -570,7 +568,6 @@ void CRouterBRouter::updateBRouterStatus() const {
     labelStatus->setText(tr("online"));
     toolConsole->setVisible(false);
     toolToggleBRouter->setVisible(false);
-    checkFastRecalc->setVisible(false);
     textBRouterOutput->clear();
     textBRouterOutput->setVisible(false);
   }
