@@ -36,10 +36,13 @@ class CRouterSetup : public QWidget, private Ui::IRouterSetup {
 
   bool hasFastRouting();
 
-  enum router_e { RouterRoutino, RouterMapquest, RouterBRouter };
+  enum router_e { RouterRoutino, RouterBRouter };
 
   void setRouterTitle(router_e, QString title);
 
+ signals:
+  void sigHasFastRouting (bool on);
+
  private slots:
   void slotSelectRouter(int i);
 
