@@ -58,7 +58,8 @@ void CRouterBRouterLocal::startBRouter() {
 
   if (brouterState == QProcess::NotRunning) {
     QStringList args;
-    args << brouter.setup->localJavaOpts.split(QRegExp("\\s+"));
+    static const QRegularExpression re("\\s+");
+    args << brouter.setup->localJavaOpts.split(re);
     args << QString("-DmaxRunningTime=%1").arg(brouter.setup->localMaxRunningTime);
     args << "-cp";
     args << brouter.setup->localBRouterJar;
@@ -185,14 +186,11 @@ void CRouterBRouterLocal::updateLocalBRouterStatus() const {
       }
     }
 
-    brouter.checkFastRecalc->setEnabled(true);
     brouter.toolToggleBRouter->setEnabled(true);
   } else {
     brouter.labelStatus->setText(tr("not installed"));
     brouter.toolConsole->setVisible(false);
     brouter.toolToggleBRouter->setEnabled(false);
-    brouter.checkFastRecalc->setEnabled(false);
   }
   brouter.toolToggleBRouter->setVisible(true);
-  brouter.checkFastRecalc->setVisible(true);
 }
