@@ -28,6 +28,7 @@
 #include "gis/rte/router/brouter/CRouterBRouterTilesSelectArea.h"
 #include "gis/rte/router/brouter/CRouterBRouterTilesSelectLayout.h"
 #include "gis/rte/router/brouter/CRouterBRouterTilesStatus.h"
+#include "misc.h"
 
 const QPoint CRouterBRouterTilesSelect::noTile = QPoint(INT_MIN, INT_MIN);
 const int CRouterBRouterTilesSelect::minTileLat = -180;
@@ -37,16 +38,19 @@ const int CRouterBRouterTilesSelect::maxTileLon = 85;
 const int CRouterBRouterTilesSelect::tileSize = 5;
 // pattern for filenames of tiles: 'E10_N20.rd5'
 const QString CRouterBRouterTilesSelect::patternTileName = QString("([EW])(\\d{1,3})_([NS])(\\d{1,3})\\.rd5$");
-const QRegExp CRouterBRouterTilesSelect::regExpTileName = QRegExp(CRouterBRouterTilesSelect::patternTileName);
+const QRegularExpression CRouterBRouterTilesSelect::regExpTileName =
+    QRegularExpression(CRouterBRouterTilesSelect::patternTileName);
 // pattern for tiles date parsing: '16-Feb-2017 20:48  '
 const QString CRouterBRouterTilesSelect::patternDate =
     "(\\d{1,2}-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-\\d{4} \\d{1,2}:\\d{2})";
-const QRegExp CRouterBRouterTilesSelect::regExpDate = QRegExp(CRouterBRouterTilesSelect::patternDate);
+const QRegularExpression CRouterBRouterTilesSelect::regExpDate =
+    QRegularExpression(CRouterBRouterTilesSelect::patternDate);
 const QString CRouterBRouterTilesSelect::formatDate = "dd-MMM-yyyy HH:mm";
 const QLocale CRouterBRouterTilesSelect::localeDate = QLocale(QLocale::English, QLocale::UnitedStates);
 // pattern for tiles size parsing: 8.2M 271K 9.3K
 const QString CRouterBRouterTilesSelect::patternSize = " {0,2}(\\d{1,3}|\\d\\.\\d)([KMG])";
-const QRegExp CRouterBRouterTilesSelect::regExpSize = QRegExp(CRouterBRouterTilesSelect::patternSize);
+const QRegularExpression CRouterBRouterTilesSelect::regExpSize =
+    QRegularExpression(CRouterBRouterTilesSelect::patternSize);
 
 CRouterBRouterTilesSelect::CRouterBRouterTilesSelect(QWidget* parent) : QWidget(parent) {
   for (int x = minTileLat; x < maxTileLat; x += tileSize) {
@@ -65,7 +69,7 @@ CRouterBRouterTilesSelect::CRouterBRouterTilesSelect(QWidget* parent) : QWidget(
   widgetSelect->show();
 
   QTemporaryFile temp;
-  temp.open();
+  openFileCheckSuccess(QIODevice::ReadWrite, temp);
   temp.close();
 
   QSettings view(temp.fileName(), QSettings::IniFormat);
@@ -253,13 +257,14 @@ void CRouterBRouterTilesSelect::initialize()
 
     const QStringList& segments = dir.entryList();
     for (const QString& segment : segments) {
-      if (regExpTileName.indexIn(segment) > -1) {
+      const QRegularExpressionMatch& match = regExpTileName.match(segment);
+      if (match.hasMatch()) {
         const QPoint& tile = tileFromFileName(segment);
         if (tile != noTile) {
           CRouterBRouterTilesStatus* status = getTileStatus(tile);
 
           const QFileInfo& info = QFileInfo(dir, segment);
-          status->localDate = info.birthTime();
+          status->localDate = info.lastModified();
           status->localSize = info.size();
           status->isLocal = true;
         }
@@ -322,7 +327,8 @@ void CRouterBRouterTilesSelect::afterSlotLoadOnlineTilesRequestFinishedRunJavasc
 
     const QString& tileName = tileMap.value("name").toString();
     // only anchors matching the desired pattern
-    if (regExpTileName.indexIn(tileName) > -1) {
+    const QRegularExpressionMatch& match = regExpTileName.match(tileName);
+    if (match.hasMatch()) {
       const QPoint& tile = tileFromFileName(tileName);
 
       if (tile != noTile) {
@@ -332,7 +338,8 @@ void CRouterBRouterTilesSelect::afterSlotLoadOnlineTilesRequestFinishedRunJavasc
 
           const QString& date = tileMap.value("date").toString();
 
-          if (regExpDate.indexIn(date) < 0) {
+          const QRegularExpressionMatch& matchDate = regExpDate.match(date);
+          if (!matchDate.hasMatch()) {
             segmentsError(tr("cannot parse: %1 is not a date").arg(date));
             update();
             return;
@@ -341,8 +348,8 @@ void CRouterBRouterTilesSelect::afterSlotLoadOnlineTilesRequestFinishedRunJavasc
           status->remoteDate = localeDate.toDateTime(date, formatDate);
 
           const QString& size = tileMap.value("size").toString();
-
-          if (regExpSize.indexIn(size) < 0) {
+          const QRegularExpressionMatch& matchSize = regExpSize.match(size);
+          if (!matchSize.hasMatch()) {
             bool ok = false;
             status->remoteSize = size.toLongLong(&ok, 10);
             if (!ok) {
@@ -351,10 +358,10 @@ void CRouterBRouterTilesSelect::afterSlotLoadOnlineTilesRequestFinishedRunJavasc
               return;
             }
           } else {
-            status->remoteSize = regExpSize.cap(1).toFloat() * (regExpSize.cap(2) == "M"   ? 1048576
-                                                                : regExpSize.cap(2) == "G" ? 1073741824
-                                                                : regExpSize.cap(2) == "K" ? 1024
-                                                                                           : 1);
+            status->remoteSize = matchSize.captured(1).toFloat() * (matchSize.captured(2) == "M"   ? 1048576
+                                                                    : matchSize.captured(2) == "G" ? 1073741824
+                                                                    : matchSize.captured(2) == "K" ? 1024
+                                                                                                   : 1);
           }
 
           if (status->isLocal && status->remoteDate > status->localDate) {
@@ -387,9 +394,10 @@ QString CRouterBRouterTilesSelect::formatSize(const qint64 size) {
 }
 
 QPoint CRouterBRouterTilesSelect::tileFromFileName(const QString& fileName) {
-  if (regExpTileName.indexIn(fileName) > -1) {
-    return QPoint(regExpTileName.cap(2).toInt() * (regExpTileName.cap(1) == "E" ? 1 : -1),
-                  regExpTileName.cap(4).toInt() * (regExpTileName.cap(3) == "N" ? 1 : -1));
+  const QRegularExpressionMatch& match = regExpTileName.match(fileName);
+  if (match.hasMatch()) {
+    return QPoint(match.captured(2).toInt() * (match.captured(1) == "E" ? 1 : -1),
+                  match.captured(4).toInt() * (match.captured(3) == "N" ? 1 : -1));
   } else {
     return noTile;
   }
@@ -459,7 +467,7 @@ void CRouterBRouterTilesSelect::slotDownload() {
 }
 
 void CRouterBRouterTilesSelect::slotDownloadReadReady() {
-  for (QNetworkReply* reply : qAsConst(tilesDownloadManagerReplies)) {
+  for (QNetworkReply* reply : std::as_const(tilesDownloadManagerReplies)) {
     if (reply->bytesAvailable() > 0) {
       try {
         const QString& fileName = reply->property("tile").toString();
@@ -522,7 +530,7 @@ void CRouterBRouterTilesSelect::slotDownloadFinished(QNetworkReply* reply) {
           status->isOutdated = false;
           status->file->close();
           QFileInfo info(*status->file);
-          status->localDate = info.birthTime();
+          status->localDate = info.lastModified();
           status->localSize = info.size();
           clearError();
         } else {
@@ -552,14 +560,14 @@ void CRouterBRouterTilesSelect::update() {
 }
 
 void CRouterBRouterTilesSelect::updateStatus() {
-  int numCurrent(0);
-  int sizeCurrent(0);
-  int numOutdated(0);
-  int sizeOutdated(0);
-  int numOutstanding(0);
-  int sizeDownloadMax(0);
-  int sizeOutstanding(0);
-  int sizeDownloaded(0);
+  quint32 numCurrent(0);
+  quint64 sizeCurrent(0);
+  quint32 numOutdated(0);
+  quint64 sizeOutdated(0);
+  quint32 numOutstanding(0);
+  quint64 sizeDownloadMax(0);
+  quint64 sizeOutstanding(0);
+  quint64 sizeDownloaded(0);
 
   bool downloading(false);
 
