@@ -16,30 +16,25 @@
 
 **********************************************************************************************/
 #include "CProjectFilterItem.h"
+
 #include <gis/CGisListWks.h>
 #include <gis/search/CSearchLineEdit.h>
 
-CProjectFilterItem::CProjectFilterItem(IGisProject* parent) : QTreeWidgetItem ((QTreeWidgetItem*)parent)
-{
-    this->parent = parent;
+CProjectFilterItem::CProjectFilterItem(IGisProject* parent) : QTreeWidgetItem((QTreeWidgetItem*)parent) {
+  this->parent = parent;
 }
 
-CProjectFilterItem::~CProjectFilterItem()
-{
-}
+CProjectFilterItem::~CProjectFilterItem() {}
 
-void CProjectFilterItem::showLineEdit(CSearch* search)
-{
-    if(treeWidget() != nullptr)
-    {
-        //new CSearchLineEdit, since destructor is called when replacing ItemWidget
-        //using QPointer and checking for isNull() is not enough, since it happens after this point
-        if(!lineEdit.isNull())
-        {
-            lineEdit->deleteLater();
-        }
-        lineEdit = new CSearchLineEdit(treeWidget(), parent, search);
-
-        treeWidget()->setItemWidget(this, CGisListWks::eColumnName, lineEdit);
+void CProjectFilterItem::showLineEdit(CSearch* search) {
+  if (treeWidget() != nullptr) {
+    // new CSearchLineEdit, since destructor is called when replacing ItemWidget
+    // using QPointer and checking for isNull() is not enough, since it happens after this point
+    if (!lineEdit.isNull()) {
+      lineEdit->deleteLater();
     }
+    lineEdit = new CSearchLineEdit(treeWidget(), parent, search);
+
+    treeWidget()->setItemWidget(this, CGisListWks::eColumnName, lineEdit);
+  }
 }
