@@ -49,7 +49,6 @@ class CQlgtTrack;
 class IQlgtOverlay;
 class CProgressDialog;
 class CPropertyTrk;
-class CFitStream;
 class CCanvas;
 
 #define ASCENT_THRESHOLD 5
@@ -117,8 +116,6 @@ class CGisItemTrk : public IGisItem, public IGisLine {
    */
   CGisItemTrk(CTrackData& trkdata, IGisProject* project);
 
-  CGisItemTrk(CFitStream& stream, IGisProject* project);
-
   virtual ~CGisItemTrk();
 
   /**
@@ -261,6 +258,11 @@ class CGisItemTrk : public IGisItem, public IGisLine {
    */
   void toRoute();
 
+  /**
+     @brief Convert the track to an area
+   */
+  void toArea();
+
   /** @defgroup ColorSource Stuff related to coloring tracks using data from different sources
 
       @{
@@ -626,11 +628,6 @@ class CGisItemTrk : public IGisItem, public IGisLine {
      @param filename
    */
   bool readTwoNav(const QString& filename);
-  /**
-     @brief Read serialized track data from a FIT file stream
-     @param stream
-   */
-  void readTrkFromFit(CFitStream& stream);
 
   /**
      @brief Consolidate points and subpoints
@@ -911,7 +908,6 @@ class CGisItemTrk : public IGisItem, public IGisLine {
   struct interpolate_t {
     bool valid = false;
     quality_e Q = eQualityCoarse;
-    alglib::ae_int_t info = -1;
     alglib::ae_int_t m = 0;
     alglib::spline1dinterpolant p;
     alglib::spline1dfitreport rep;
