@@ -21,31 +21,30 @@
 
 #include <gis/trk/CGisItemTrk.h>
 
-#include "ui_IListTrkPts.h"
 #include <QWidget>
 
-class CListTrkPts : public QWidget, public INotifyTrk, private Ui::IListTrkPts
-{
-    Q_OBJECT
-public:
-    CListTrkPts(QWidget* parent);
-    virtual ~CListTrkPts();
+#include "ui_IListTrkPts.h"
 
-    void setTrack(CGisItemTrk* track);
+class CListTrkPts : public QWidget, public INotifyTrk, private Ui::IListTrkPts {
+  Q_OBJECT
+ public:
+  CListTrkPts(QWidget* parent);
+  virtual ~CListTrkPts();
 
-    void updateData() override;
-    void setMouseFocus(const CTrackData::trkpt_t* pt) override;
-    void setMouseRangeFocus(const CTrackData::trkpt_t* pt1, const CTrackData::trkpt_t* pt2) override;
-    void setMouseClickFocus(const CTrackData::trkpt_t* pt) override {}
+  void setTrack(CGisItemTrk* track);
 
-private:
-    void setMouseFocus(qint32 idx);
-    void addTableRow(bool focus, const CTrackData::trkpt_t& trkpt, bool isInRange, QTextStream& stream);
-    QString getTh(const QString& str, const QFontMetrics& fm);
-    CGisItemTrk* trk = nullptr;
-    static constexpr auto maxLines = 5;
-    qint32 idxFocus = NOIDX;
+  void updateData() override;
+  void setMouseFocus(const CTrackData::trkpt_t* pt) override;
+  void setMouseRangeFocus(const CTrackData::trkpt_t* pt1, const CTrackData::trkpt_t* pt2) override;
+  void setMouseClickFocus(const CTrackData::trkpt_t* pt) override {}
+
+ private:
+  void setMouseFocus(qint32 idx);
+  void addTableRow(bool focus, const CTrackData::trkpt_t& trkpt, bool isInRange, QTextStream& stream);
+  QString getTh(const QString& str, const QFontMetrics& fm);
+  CGisItemTrk* trk = nullptr;
+  static constexpr auto maxLines = 5;
+  qint32 idxFocus = NOIDX;
 };
 
-#endif //CLISTTRKPTS_H
-
+#endif  // CLISTTRKPTS_H
