@@ -75,6 +75,7 @@ CScrOptTrk::CScrOptTrk(CGisItemTrk* trk, const QPoint& point, IMouse* parent) :
   connect(toolAddElevation, &QToolButton::clicked, this, &CScrOptTrk::slotAddElevation);
   connect(toolAddInfo, &QToolButton::clicked, this, &CScrOptTrk::slotAddInfo);
   connect(toolToRoute, &QToolButton::clicked, this, &CScrOptTrk::slotToRoute);
+  connect(toolToArea, &QToolButton::clicked, this, &CScrOptTrk::slotToArea);
 
   connect(label, &QLabel::linkActivated, this, &CScrOptTrk::slotLinkActivated);
 
@@ -198,6 +199,13 @@ void CScrOptTrk::slotToRoute() {
   close();
 }
 
+void CScrOptTrk::slotToArea() {
+  CScrOptSemaphoreLocker lock(*this);
+  hide();
+  CGisWorkspace::self().convertTrackToArea(key);
+  close();
+}
+
 void CScrOptTrk::slotTags() {
   CScrOptSemaphoreLocker lock(*this);
   hide();
