@@ -20,31 +20,28 @@
 
 #include <QVector>
 
-typedef struct
-{
-    int nDatumEPSGCode;
-    int nMapInfoDatumID;
-    const char* pszOGCDatumName;
-    int nEllipsoid;
-    double dfShiftX;
-    double dfShiftY;
-    double dfShiftZ;
-    double dfDatumParm0;      /* RotX */
-    double dfDatumParm1;      /* RotY */
-    double dfDatumParm2;      /* RotZ */
-    double dfDatumParm3;      /* Scale Factor */
-    double dfDatumParm4;      /* Prime Meridian */
+typedef struct {
+  int nDatumEPSGCode;
+  int nMapInfoDatumID;
+  const char* pszOGCDatumName;
+  int nEllipsoid;
+  double dfShiftX;
+  double dfShiftY;
+  double dfShiftZ;
+  double dfDatumParm0; /* RotX */
+  double dfDatumParm1; /* RotY */
+  double dfDatumParm2; /* RotZ */
+  double dfDatumParm3; /* Scale Factor */
+  double dfDatumParm4; /* Prime Meridian */
 } MapInfoDatumInfo;
 
-
-struct MapInfoSpheroidInfo
-{
-    int nMapInfoId;
-    const char* pszMapinfoName;
-    double dfA;                  /* semi major axis in meters */
-    double dfInvFlattening;      /* Inverse flattening */
+struct MapInfoSpheroidInfo {
+  int nMapInfoId;
+  const char* pszMapinfoName;
+  double dfA;             /* semi major axis in meters */
+  double dfInvFlattening; /* Inverse flattening */
 };
 
 extern const QVector<MapInfoDatumInfo> asDatumInfoList;
 extern const QVector<MapInfoSpheroidInfo> asSpheroidInfoList;
-#endif                           //MITAB_H
+#endif  // MITAB_H
