@@ -21,26 +21,23 @@
 
 #include <QMutex>
 
-class CTryMutexLocker
-{
-public:
-    CTryMutexLocker(QMutex& mutex) : m_mutex(mutex){}
-    ~CTryMutexLocker()
-    {
-        if(needsUnlock)
-        {
-            m_mutex.unlock();
-        }
+template <typename T>
+class CTryMutexLocker {
+ public:
+  CTryMutexLocker(T& mutex) : m_mutex(mutex) {}
+  ~CTryMutexLocker() {
+    if (needsUnlock) {
+      m_mutex.unlock();
     }
-    bool try_lock()
-    {
-        needsUnlock = m_mutex.tryLock();
-        return needsUnlock;
-    }
-private:
-    QMutex& m_mutex;
-    bool needsUnlock {false};
+  }
+  bool try_lock() {
+    needsUnlock = m_mutex.tryLock();
+    return needsUnlock;
+  }
+
+ private:
+  T& m_mutex;
+  bool needsUnlock{false};
 };
 
-#endif //CTRYMUTEXLOCKER_H
-
+#endif  // CTRYMUTEXLOCKER_H
