@@ -28,14 +28,16 @@ class QMenu;
 class CMapTreeWidget : public QTreeWidget {
   Q_OBJECT
  public:
-  CMapTreeWidget(QWidget* parent) : QTreeWidget(parent) {}
+  CMapTreeWidget(QWidget* parent);
+
+  void restoreItemWidgetDelayed(CMapItem* map);
 
  signals:
   void sigChanged();
 
  protected:
   void dragEnterEvent(QDragEnterEvent* e) override;
-  void dragMoveEvent(QDragMoveEvent* e) override;
+  void dragLeaveEvent(QDragLeaveEvent* e) override;
   void dropEvent(QDropEvent* e) override;
 };
 
@@ -48,13 +50,31 @@ class CMapList : public QWidget, private Ui::IMapList {
   virtual ~CMapList();
 
   void clear();
-  void sort();
   int count();
   CMapItem* item(int i);
   operator QTreeWidget*() { return treeWidget; }
 
+  /**
+   * @brief Show/hide hints depending on the map list's state
+   */
   void updateHelpText();
 
+  /**
+   * @brief Add map item to the list
+   *
+   * Add the item as top level item and set the item's widget. Connect
+   * the item's signals to properly handle changes.
+   *
+   * @param map
+   */
+  void addMap(CMapItem* map);
+
+  /**
+   * @brief Move map item to top of list
+   * @param map
+   */
+  void moveMapToTop(CMapItem* map);
+
  signals:
   void sigChanged();
 
@@ -62,9 +82,9 @@ class CMapList : public QWidget, private Ui::IMapList {
   static void slotMapHonk();
 
  private slots:
-  void slotActivate();
   void slotMoveUp();
   void slotMoveDown();
+  void slotRemove();
   void slotReloadMaps();
   void slotContextMenu(const QPoint& point);
   void slotFilter(const QString& str);
