@@ -33,6 +33,12 @@ IMapOnline::IMapOnline(CMapDraw* parent) : IMap(eFeatVisibility | eFeatTileCache
   connect(this, &IMapOnline::sigQueueChanged, this, &IMapOnline::slotQueueChanged);
 }
 
+IMapOnline::~IMapOnline() {
+  if (map) {
+    map->reportStatusToCanvas(name, "");
+  }
+}
+
 bool IMapOnline::httpsCheck(const QString& url) {
   if (url.startsWith("https", Qt::CaseInsensitive) && !QSslSocket::supportsSsl()) {
     QString msg =
