@@ -27,6 +27,7 @@
 #include "helpers/CTryMutexLocker.h"
 #include "helpers/CWptIconManager.h"
 #include "mouse/CScrOptSelect.h"
+#include "poi/IPoiFile.h"
 #include "poi/IPoiItem.h"
 
 QMutex CMouseSelect::mutex;
@@ -79,7 +80,7 @@ void CMouseSelect::findItems(QList<IGisItem*>& items) {
     cntTrk = 0;
     cntRte = 0;
     cntOvl = 0;
-    for (IGisItem* item : qAsConst(items)) {
+    for (IGisItem* item : std::as_const(items)) {
       itemKeys << item->getKey();
       switch (item->type()) {
         case IGisItem::eTypeWpt:
@@ -154,16 +155,17 @@ void CMouseSelect::draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QRect&
   QList<IGisItem*> items;
   findItems(items);
 
-  for (IGisItem* item : qAsConst(items)) {
+  for (IGisItem* item : std::as_const(items)) {
     item->drawHighlight(p);
   }
 
-  for (QPointF pos : qAsConst(posPoiHighlight)) {
+  const QImage& iconHighlight = IPoiFile::iconHighlight();
+  for (QPointF pos : std::as_const(posPoiHighlight)) {
     if (pos != NOPOINTF) {
       gis->convertRad2Px(pos);
-      QRectF r(0, 0, 42, 42);
+      QRectF r = iconHighlight.rect();
       r.moveCenter(pos);
-      p.drawImage(r, QImage("://cursors/poiHighlightRed.png"));
+      p.drawImage(r, iconHighlight);
     }
   }
 
