@@ -19,34 +19,25 @@
 #ifndef CSCROPTSELECT_H
 #define CSCROPTSELECT_H
 
-
 #include "gis/IGisItem.h"
 #include "mouse/IScrOpt.h"
 #include "ui_IScrOptSelect.h"
 
-class CScrOptSelect : public IScrOpt, public Ui::IScrOptSelect
-{
-    Q_OBJECT
-public:
-    CScrOptSelect(IMouse* mouse);
-    virtual ~CScrOptSelect();
+class CScrOptSelect : public IScrOpt, public Ui::IScrOptSelect {
+  Q_OBJECT
+ public:
+  CScrOptSelect(IMouse* mouse);
+  virtual ~CScrOptSelect();
 
-    void draw(QPainter& p) override
-    {
-    }
+  void draw(QPainter& p) override {}
 
-    IGisItem::selflags_t getModeSelection() const
-    {
-        return modeSelection;
-    }
+  IGisItem::selflags_t getModeSelection() const { return modeSelection; }
 
-private slots:
-    void slotModeSwitch(IGisItem::selection_e mode, bool checked);
+ private slots:
+  void slotModeSwitch(IGisItem::selection_e mode, bool checked);
 
-
-private:
-    IGisItem::selflags_t modeSelection = IGisItem::eSelectionNone;
+ private:
+  IGisItem::selflags_t modeSelection = IGisItem::eSelectionNone;
 };
 
-#endif //CSCROPTSELECT_H
-
+#endif  // CSCROPTSELECT_H
