@@ -22,6 +22,7 @@
 
 #include "CMainWindow.h"
 #include "helpers/CSettings.h"
+#include "misc.h"
 #include "poi/CPoiFileItem.h"
 #include "poi/CPoiList.h"
 #include "poi/CPoiPathSetup.h"
@@ -104,7 +105,7 @@ void CPoiDraw::setupPoiPath(const QString& path) {
 void CPoiDraw::setupPoiPath(const QStringList& paths) {
   poiPaths = paths;
 
-  for (CPoiDraw* poi : qAsConst(pois)) {
+  for (CPoiDraw* poi : std::as_const(pois)) {
     QStringList keys;
     poi->saveActivePoisList(keys);
     poi->buildPoiList();
@@ -180,7 +181,7 @@ void CPoiDraw::buildPoiList() {
   QMutexLocker lock(&CPoiFileItem::mutexActivePois);
   poiList->clear();
 
-  for (const QString& path : qAsConst(poiPaths)) {
+  for (const QString& path : std::as_const(poiPaths)) {
     QDir dir(path);
     // find available maps
     const QStringList& files = dir.entryList(supportedFormats, QDir::Files | QDir::Readable, QDir::Name);
@@ -195,7 +196,7 @@ void CPoiDraw::buildPoiList() {
 
       // calculate MD5 hash from the file's first 1024 bytes
       QFile f(dir.absoluteFilePath(filename));
-      f.open(QIODevice::ReadOnly);
+      openFileCheckSuccess(QIODevice::ReadOnly, f);
       md5.reset();
       md5.addData(f.read(1024));
       item->key = md5.result().toHex();
