@@ -31,6 +31,9 @@ CPoiPropSetup::CPoiPropSetup(IPoiFile* poifile, CPoiDraw* poi) : IPoiProp(poifil
 
   poifile->addTreeWidgetItems(treeWidgetCategories);
   treeWidgetCategories->sortItems(eTreeColumnDisplayName, Qt::SortOrder::AscendingOrder);
+  treeWidgetCategories->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
+  treeWidgetCategories->resizeColumnToContents(1);
+
   connect(treeWidgetCategories, SIGNAL(itemChanged(QTreeWidgetItem*, int)), poifile,
           SLOT(slotCheckedStateChanged(QTreeWidgetItem*)));
 }
