@@ -117,7 +117,7 @@ void CQmsDb::addFolder(CQlgtFolder& folder) {
       generate key and info text properly
    */
   CDBProject project(folder);
-  for (quint64 id : qAsConst(folder.items)) {
+  for (quint64 id : std::as_const(folder.items)) {
     quint64 idChild = mapItemIDs[id];
     query.prepare("SELECT type FROM items WHERE id=:id");
     query.bindValue(":id", idChild);
