@@ -30,9 +30,10 @@ void CAppSetupLinux::initQMapShack() {
   prepareGdal("", "");
 
   // setup translators
-  QString resourceDir = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+  QString resourceDir = QLibraryInfo::path(QLibraryInfo::TranslationsPath);
   QString translationPath = QCoreApplication::applicationDirPath();
-  translationPath.replace(QRegExp("bin$"), "share/qmapshack/translations");
+  static const QRegularExpression re("bin$");
+  translationPath.replace(re, "share/qmapshack/translations");
   prepareTranslator(resourceDir, "qt_");
   prepareTranslator(translationPath, "qmapshack_");
 
