@@ -19,34 +19,32 @@
 #ifndef CAPPSETUPMAC_H
 #define CAPPSETUPMAC_H
 
-#include "setup/IAppSetup.h"
-
 #include <QtCore>
 
+#include "setup/IAppSetup.h"
 
-class CAppSetupMac : public IAppSetup
-{
-public:
-    void initQMapShack() override;
-    QString routinoPath(QString xmlFile) override;
-    QString defaultCachePath() override;
-    QString userDataPath(QString subdir = 0) override;
-    QString logDir() override;
-    QString findExecutable(const QString& name) override { return QStandardPaths::findExecutable(name); }
-    QString helpFile() override;
+class CAppSetupMac : public IAppSetup {
+ public:
+  void initQMapShack() override;
+  QString routinoPath(QString xmlFile) override;
+  QString defaultCachePath() override;
+  QString userDataPath(QString subdir = 0) override;
+  QString logDir() override;
+  QString findExecutable(const QString& name) override { return QStandardPaths::findExecutable(name); }
+  QString helpFile() override;
 
-private:
-    QDir getApplicationDir(QString subdir);
-    void migrateDirContent(QString dest);
-    void extendPath();
+ private:
+  QDir getApplicationDir(QString subdir);
+  void migrateDirContent(QString dest);
+  void extendPath();
 
-    static QString relTranslationDir;
-    static QString relRoutinoDir;
-    static QString relGdalDir;
-    static QString relProjDir;
-    static QString relHelpDir;
-    static QString relBinDir;
-    static QString relLogDir;
+  static QString relTranslationDir;
+  static QString relRoutinoDir;
+  static QString relGdalDir;
+  static QString relProjDir;
+  static QString relHelpDir;
+  static QString relBinDir;
+  static QString relLogDir;
 };
 
-#endif // CAPPSETUPMAC_H
+#endif  // CAPPSETUPMAC_H
