@@ -20,43 +20,27 @@
 
 #include <QApplication>
 #include <QCommandLineParser>
-#include <iostream>
 
 CAppOpts* CCommandProcessor::processOptions(const QStringList& arguments) {
   QCommandLineParser parser;
-  QCommandLineOption helpOption = parser.addHelpOption();  // h help
+  parser.addHelpOption();
+  parser.addVersionOption();
 
-  QCommandLineOption debugOption(QStringList() << "d"
-                                               << "debug",
-                                 tr("Print debug output to console."));
+  QCommandLineOption debugOption(QStringList() << "d" << "debug", tr("Print debug output to console."));
   parser.addOption(debugOption);
 
-  QCommandLineOption logfileOption(QStringList() << "f"
-                                                 << "logfile",
-                                   tr("Print debug output to logfile (temp. path)."));
+  QCommandLineOption logfileOption(QStringList() << "f" << "logfile", tr("Print debug output to logfile (temp. path)."));
   parser.addOption(logfileOption);
 
-  QCommandLineOption nosplashOption(QStringList() << "n"
-                                                  << "no-splash",
-                                    tr("Do not show splash screen."));
+  QCommandLineOption nosplashOption(QStringList() << "n" << "no-splash", tr("Do not show splash screen."));
   parser.addOption(nosplashOption);
 
-  QCommandLineOption configOption(QStringList() << "c"
-                                                << "config",
-                                  tr("File with QMapShack configuration."), tr("file"));
+  QCommandLineOption configOption(QStringList() << "c" << "config", tr("File with QMapShack configuration."), tr("file"));
   parser.addOption(configOption);
 
   parser.addPositionalArgument("files", tr("Files for future use."));
 
-  if (!parser.parse(arguments)) {
-    std::cerr << parser.errorText().toUtf8().constData();
-    std::cerr << parser.helpText().toUtf8().constData();
-    exit(1);
-  }
-  if (parser.isSet(helpOption)) {
-    std::cout << parser.helpText().toUtf8().constData();
-    exit(0);
-  }
+  parser.process(arguments);
 
   return new CAppOpts(parser.isSet(debugOption), parser.isSet(logfileOption), parser.isSet(nosplashOption),
                       parser.value(configOption), parser.positionalArguments());
